@@ -244,10 +244,14 @@ void SMPStyleWidget::show(ParagraphStyle *pstyle, QList<ParagraphStyle> &pstyles
 	const ParagraphStyle *parent = dynamic_cast<const ParagraphStyle*>(pstyle->parentStyle());
 	m_hasParent = pstyle->hasParent() && parent != nullptr && parent->hasName() && pstyle->parent() != "";
 
+	int  oldLineSpacingModeIndex = lineSpacingMode->currentIndex();
+	bool lineSpacingModeBlocked = lineSpacingMode->blockSignals(true);
 	lineSpacingMode->clear();
-	lineSpacingMode->addItem( tr("Fixed Linespacing"));
-	lineSpacingMode->addItem( tr("Automatic Linespacing"));
-	lineSpacingMode->addItem( tr("Align to Baseline Grid"));
+	lineSpacingMode->addItem(tr("Fixed Linespacing"));
+	lineSpacingMode->addItem(tr("Automatic Linespacing"));
+	lineSpacingMode->addItem(tr("Align to Baseline Grid"));
+	lineSpacingMode->setCurrentIndex(oldLineSpacingModeIndex);
+	lineSpacingMode->blockSignals(lineSpacingModeBlocked);
 	
 //	optMarginCombo->clear();
 //	optMarginCombo->addItem(tr("None"), ParagraphStyle::OM_None);
@@ -404,7 +408,7 @@ void SMPStyleWidget::show(ParagraphStyle *pstyle, QList<ParagraphStyle> &pstyles
 	}
 	else
 	{
-		lineSpacingMode->setCurrentIndex(pstyle->lineSpacingMode());
+		lineSpacingMode->setCurrentItem(pstyle->lineSpacingMode());
 		lineSpacing->setValue(pstyle->lineSpacing());
 		spaceAbove->setValue(pstyle->gapBefore());
 		spaceBelow->setValue(pstyle->gapAfter());
